@@ -8,6 +8,8 @@
 #' these values for the first independent variable
 #' @param iv_2_values restrict all analyses to observations having
 #' these values for the second independent variable
+#' @param sigfigs number of significant digits to which to round
+#' values in anova table (default = 3)
 #' @param robust if \code{TRUE}, conduct a robust ANOAVA in addition.
 #' @param iterations number of bootstrap samples for robust ANOVA.
 #' The default is set at 2000, but consider increasing the number
@@ -52,7 +54,8 @@ two_way_anova <- function(
   iv_2_name = NULL,
   iv_1_values = NULL,
   iv_2_values = NULL,
-  robust = TRUE,
+  sigfigs = 3,
+  robust = FALSE,
   iterations = 2000,
   plot = FALSE,
   error_bar = "ci",
@@ -63,12 +66,18 @@ two_way_anova <- function(
   position_dodge = 0.13,
   legend_position = "right",
   output = NULL) {
+  # bind the vars locally to the function
+  p <- NULL
+  # default output
+  if (is.null(output)) {
+    output <- "anova_table"
+  }
   # convert data to data table
-  dt1 <- data.table::setDT(copy(data))
+  dt1 <- setDT(copy(data))
   dt1 <- dt1[, c(iv_1_name, iv_2_name, dv_name), with = FALSE]
   # convert iv to factors
   for (col in c(iv_1_name, iv_2_name)) {
-    data.table::set(dt1, j = col, value = as.factor(dt1[[col]]))
+    set(dt1, j = col, value = as.factor(dt1[[col]]))
   }
   # remove na
   dt2 <- stats::na.omit(dt1)
@@ -96,9 +105,13 @@ two_way_anova <- function(
   ),
   keyby = c(iv_1_name, iv_2_name)
   ]
+  if (output == "group_stats") {
+    return(group_stats)
+  }
   message(paste0("\nGroup Statistics on ", dv_name, ":"))
   print(group_stats)
-  if (plot == TRUE) {
+  # print or return plot
+  if (plot == TRUE | output == "plot") {
     g1 <- kim::plot_group_means(
       data = dt2,
       dv_name = dv_name,
@@ -110,10 +123,13 @@ two_way_anova <- function(
       error_bar_tip_width = error_bar_tip_width,
       position_dodge = position_dodge,
       legend_position = legend_position)
+    if (output == "plot") {
+      return(g1)
+    }
     print(g1)
   }
   # order the data table
-  data.table::setorderv(dt2, c(iv_1_name, iv_2_name))
+  setorderv(dt2, c(iv_1_name, iv_2_name))
   # levene's test
   formula_1 <- stats::as.formula(
     paste0(dv_name, " ~ ", iv_1_name, " * ", iv_2_name)
@@ -126,15 +142,29 @@ two_way_anova <- function(
   print(levene_test_result)
   if (levene_test_p_value < .05) {
     message(paste0(
-      "The homogeneity of variance assumption is violated",
-      " for the ANOVA results below."
-    ))
+      "The homogeneity of variance assumption is violated."))
+  }
+  if (output == "levene_test_result") {
+    return(levene_test_result)
   }
   # anova instead of regression
   model_1 <- stats::aov(formula = formula_1, data = dt2)
   anova_table <- car::Anova(model_1, type = 3)
+  source <- row.names(anova_table)
+  setDT(anova_table)
+  anova_table <- data.table(source, anova_table)
+  names(anova_table) <- c("source", "type_3_sum_sq", "df", "f", "p")
+  cols_to_round <- c("type_3_sum_sq", "f")
+  for (j in cols_to_round) {
+    set(anova_table, j = j, value = signif(anova_table[[j]], sigfigs))
+  }
+  anova_table[, p := kim::pretty_round_p_value(p)]
   message("\nANOVA Results:")
   print(anova_table)
+  # output by type
+  if (output == "anova_table") {
+    return(anova_table)
+  }
   if (robust == TRUE) {
     # robust anova
     robust_anova_results <-
@@ -142,6 +172,9 @@ two_way_anova <- function(
                      data = dt2, est = "mom",
                      nboot = iterations
       )
+    if (output == "robust_anova_results") {
+      return(robust_anova_results)
+    }
     message("\nRobust ANOVA Results:")
     print(robust_anova_results)
     robust_anova_post_hoc_results <-
@@ -157,26 +190,7 @@ two_way_anova <- function(
     message("\nRobust ANOVA Post Hoc Test Contrasts:")
     print(robust_anova_post_hoc_contrast)
   }
-  # default output
-  if (is.null(output)) {
-    output <- "anova_table"
-  }
-  # output by type
-  if (output == "anova_table") {
-    invisible(anova_table)
-  }
-  if (output == "group_stats") {
-    invisible(group_stats)
-  }
-  if (output == "plot") {
-    invisible(g1)
-  }
-  if (output == "levene_test_result") {
-    invisible(levene_test_result)
-  }
-  if (output == "robust_anova_results") {
-    invisible(robust_anova_results)
-  }
+  # output for robust anova
   if (output == "robust_anova_post_hoc_results") {
     invisible(robust_anova_post_hoc_results)
   }
